@@ -5,7 +5,7 @@ from .protocolHandler import *
 from . import LOGGER
 import time
 
-tarVersion = "V20210823"
+tarVersion = "V20210824"
 
 VersionDetail = "当前版本:" + tarVersion + """
 ---------------------------版本更新信息----------------------------
@@ -15,6 +15,11 @@ V20210818:
 
 V20210823:
 1、添加了硬件语音联动状态查询接口:def isSpeechAutoMode(self):
+
+V20210824:
+1、修复了温湿度获取API显示错位:def getTemperatureHumidity(self, moduleID):
+2、修复了语音识别API未识别到时引发错误的BUG:def recognizeSpeech(self, moduleID):
+3、增加了识别一条新语句的方法：def recognizeNewSpeech(self, moduleID):
 ------------------------------------------------------------------
 """
 
@@ -24,7 +29,7 @@ class GatewayDict():
     gestureEncode = {0: "None", 1: "left", 2: "right", 3: "up", 4: "down"}
     voiceEncodeV2 = {
         # 0:"未识别到语音",
-        # 1:"小飞同学",
+        1: "小飞同学",
         2: "打开灯光",
         3: "关闭灯光",
         4: "开一下灯",
@@ -168,6 +173,7 @@ class GatewayDriver(BaseDriver, GatewayDict):
     def __init__(self, host="localhost", port=4001):
         super().__init__(host, port)
         self.addProtocol(K12ProtocolHandler())
+        self.wait_time = 1
         self.status = {}
 
     # 此处result为按协议定义的字段解析过的dict
@@ -215,8 +221,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 单参数状态获取返回为true or false
     def isSingleStatusTrueOrFalse(self, moduleID=None, moduleAddr=0):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), moduleAddr,
-                                   0x01, 0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   moduleAddr, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -225,6 +231,9 @@ class GatewayDriver(BaseDriver, GatewayDict):
         else:
             return False
 
+    def setWaitTime(self, wait_recv_time=1):
+        self.wait_time = wait_recv_time
+
     def getVersion(self):
         return tarVersion
 
@@ -330,29 +339,34 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 手势
     def checkGesture(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x00A6, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x00A6, 0x01, 0)
         if recv_buf is not None:
             return self.gestureEncode[recv_buf["data"]["数据"]]
         else:
             return False
 
     # 语音识别
-    def recognizeSpeech(self, moduleID=None):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x00b8, 0x01,
-                                   0)
-        current_speech = recv_buf["data"]["数据"]
-        if self.last_speech != current_speech:
-            self.last_speech = current_speech
-            # self.log("e",current_speech)
-            if self.last_speech in self.voiceEncodeV2:
-                return self.last_speech
+    def recognizeSpeech(self, moduleID):
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x00b8, 0x01, 0)
+        if recv_buf is not None:
+            current_speech = recv_buf["data"]["数据"]
+            if current_speech in self.voiceEncodeV2:
+                return current_speech
+        return False
+
+    def recognizeNewSpeech(self, moduleID):
+        recv_buf = self.recognizeSpeech(moduleID)
+        if recv_buf is not False and recv_buf != self.last_speech:
+            self.last_speech = recv_buf
+            return self.last_speech
         return False
 
     # 场景代码-红外对射场景
     def getIRDegree(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x002C, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x002C, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -363,8 +377,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外反射传感器
     def getAIRDegree(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0036, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0036, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -375,8 +389,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外转发
     def getIRSend(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x009A, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x009A, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -384,8 +398,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-红外接收
     def getIRRecv(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x009C, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x009C, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -393,8 +407,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-人体
     def checkHuman(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x003C, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x003C, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -405,8 +419,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-获取光照值场景
     def getShineDegree(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x002A, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x002A, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -414,8 +428,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-烟雾
     def checkSmoke(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0034, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0034, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -423,8 +437,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-声音
     def checkSound(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x003A, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x003A, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -435,8 +449,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-结露
     def checkRain(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x002E, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x002E, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -444,8 +458,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-火焰
     def checkFire(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0038, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0038, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -456,8 +470,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-燃气
     def checkCGas(self, moduleID=None):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x00A4, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x00A4, 0x01, 0)
         if recv_buf is not None:
             return recv_buf["data"]["数据"]
         else:
@@ -465,11 +479,11 @@ class GatewayDriver(BaseDriver, GatewayDict):
 
     # 场景代码-温湿度
     def getTemperatureHumidity(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0014, 0x02,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0014, 0x02, 0)
         if recv_buf is not None:
-            return [((recv_buf["data"]["数据"] >> 16) & 0xFFFF) / 10.0,
-                    ((recv_buf["data"]["数据"]) & 0xFFFF) / 10.0]
+            return [((recv_buf["data"]["数据"]) & 0xFFFF) / 10.0,
+                    ((recv_buf["data"]["数据"] >> 16) & 0xFFFF) / 10.0]
         else:
             return [-1, -1]
 
@@ -492,8 +506,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
     ################### 以下是执行器状态查询 #####################
 
     def isFanOpen(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0048, 0x01,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0048, 0x01, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] == 1:
                 return True
@@ -503,8 +517,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     def isRGBLightOpen(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x009e, 0x03,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x009e, 0x03, 0)
         if recv_buf is not None:
             if recv_buf["data"]["数据"] != 0:
                 return True
@@ -514,8 +528,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return False
 
     def currentRGBLight(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x009e, 0x03,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x009e, 0x03, 0)
         if recv_buf is not None:
             return [((recv_buf["data"]["数据"] >> 32) & 0xFFFF),
                     ((recv_buf["data"]["数据"] >> 16) & 0xFFFF),
@@ -545,8 +559,8 @@ class GatewayDriver(BaseDriver, GatewayDict):
             return -1
 
     def audioPlayerCurrentPlayed(self, moduleID):
-        recv_buf = self.queryOrder(1, "03号查询指令", int(moduleID), 0x0096, 0x02,
-                                   0)
+        recv_buf = self.queryOrder(self.wait_time, "03号查询指令", int(moduleID),
+                                   0x0096, 0x02, 0)
         if recv_buf is not None:
             return [((recv_buf["data"]["数据"] >> 16) & 0xFFFF),
                     ((recv_buf["data"]["数据"]) & 0xFFFF)]
